@@ -1,5 +1,8 @@
 from .fields import (  # noqa: F401
     ARRAY,
+    CIDR,
+    INET,
     JSONB,
+    MACADDR,
     UUID,
 )
